Release History
===============

`1.0.0`_ (2 Jul 2022)
---------------------
- Renamed primary branch to "main"
- Drop Python 2.7 support
- Add type annotations
- Rewrite examples to use asyncio instead of the Tornado IOLoop
- Drop support for older Tornado versions (6.0+ is required now)

`0.0.6`_ (8 Apr 2019)
---------------------
- Make json encoder configurable.
- Add example of using Open API and JSON schema validation together

`0.0.5`_ (4 Apr 2019)
---------------------
- Make content type configurable.

`0.0.4`_ (2 Apr 2019)
---------------------
- Made compatible with Python 2.7, Tornado 4.4, Tornado 4.5, & Tornado 5.

`0.0.2`_ (1 Apr 2019)
---------------------
- Add :exc:`problemdetails.Problem`

`0.0.1`_ (31 Mar 2019)
----------------------
- Initial alpha release containing a very simple implementation.

.. _Next Release: https://github.com/dave-shawley/tornado-problem-details/compare/1.0.0...main
.. _1.0.0: https://github.com/dave-shawley/tornado-problem-details/compare/0.0.6...1.0.0
.. _0.0.6: https://github.com/dave-shawley/tornado-problem-details/compare/0.0.5...0.0.6
.. _0.0.5: https://github.com/dave-shawley/tornado-problem-details/compare/0.0.4...0.0.5
.. _0.0.4: https://github.com/dave-shawley/tornado-problem-details/compare/0.0.2...0.0.4
.. _0.0.2: https://github.com/dave-shawley/tornado-problem-details/compare/0.0.1...0.0.2
.. _0.0.1: https://github.com/dave-shawley/tornado-problem-details/compare/0.0.0...0.0.1
